===============
Acknowledgments
===============

A lot of people were involved in the creation of mosaik and mosaik wouldn't be
what it is today without any of them:

- *Martin Tröschel* and *Astrid Nieße* had the original idea for a tool that
  lets you integrate existing simulators to perform large-scale Smart Grid
  simulations. They also accompanied mosaik's development many years as group
  and project leaders and provided the necessary time and resources for
  mosaik's development.

- *Steffen Schütte* wrote his PhD around mosaik. He and *Stefan Scherfke*
  are the primary authors of mosaik 1.

- *Ontje Lünsdorf* not only contributed code to mosaik 1, but also a lot
  of ideas. He held countless discussions with Steffen and Stefan whose results
  often greatly improved mosaik.

- *Stefan Scherfke* is the primary author of mosaik 2.0 and 2.1.

- *Sebastian Rohjans* and *Sebastian Lehnhoff* accompanied mosaik's development
  as group and scientific leaders. They also put lots of effort into making
  mosaik open-source software.

- *Okko Nannen* and *Florian Schlögl* joined the team in May / July 2014.

We'd also like to thank everyone who worked with mosaik and gave us feedback to
make it better.
